@@ -54,7 +54,7 @@ class BaseClient:
             url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 300:
             logger.error(f"{response.status_code}  {url} failed. {response.text} ; data:{json}")
-            raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
+            raise InvalidAPIResponse(f"{response.status_code}  {url} {json} {response.text}")
         return response
 
     def _get_url_by_caller(self, suffix: str):
@@ -117,10 +117,10 @@ class BaseClient:
         logger.debug(f"Fetching {url} params: {params}")
         response = self.session.get(
             url, params=params, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
-        logger.debug(f"Received Response {response.json()}")
         if response.status_code > 202:
-            logger.error(f"{response.status_code}  {url} failed. {response.text}")
-            raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
+            logger.error(f"{response.status_code}  {url} {params} failed. {response.text}")
+            raise InvalidAPIResponse(f"{response.status_code} {url} {params} {response.text}")
+        logger.debug(f"Received Response {response.text}")
         return response
 
     def put(self, url: str, json: Dict[str, Any], headers:Optional[Dict[str,str]]=None):
@@ -131,8 +131,8 @@ class BaseClient:
         json["sessionRestriction"] = "false"
         response = self.session.put(url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 202:
-            logger.error(f"{response.status_code}  {url} failed. {response.text}")
-            raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
+            logger.error(f"{response.status_code}  {url} {json} failed. {response.text}")
+            raise InvalidAPIResponse(f"{response.status_code}  {url} {json} {response.text}")
         return response
 
     def project(self, project_id: str) -> "projects.Project":
