@@ -47,10 +47,11 @@ class TimePoint(MixinConfig):
         detections: List["deeplabel.infer.videos.detections.Detection"],
         ignore_thresh: float = 2,
     ) -> List["TimePoint"]:
-        if not detections: return []
-        assert (isinstance(detections, List) and isinstance(detections[0],
-                deeplabel.infer.videos.detections.Detection)), \
-                f"detections should be of type List[deeplabel.infer.videos.detections.Detection]"
+        if not detections:
+            return []
+        assert isinstance(detections, List) and isinstance(
+            detections[0], deeplabel.infer.videos.detections.Detection
+        ), f"detections should be of type List[deeplabel.infer.videos.detections.Detection]"
         time_points = []
         time_arr = sorted(list(set([det.time for det in detections])))
         time_points = [{"startTime": time_arr[0], "endTime": time_arr[0],}]
@@ -72,8 +73,9 @@ class GraphNodeAnnotation(MixinConfig):
 
 class VideoTask(DeeplabelBase):
     video_task_id: str
-    video: VideoTaskVideoId = Field(..., alias='videoId')
+    video: VideoTaskVideoId = Field(..., alias="videoId")
     graph_id: str
+    project_id: str
     graph_node: GraphNodeAnnotation = Field(..., alias="graphNodeId")
     is_shown: bool
     status: VideoTaskStatus
@@ -87,7 +89,7 @@ class VideoTask(DeeplabelBase):
         resp = client.get("/videos/tasks", params=params)
         tasks = resp.json()["data"]["videoTasks"]
         # Checkout https://lidatong.github.io/dataclasses-json/#use-my-dataclass-with-json-arrays-or-objects
-        tasks = [cls(**task, client=client) for task in tasks if task['name']!='EDIT']
+        tasks = [cls(**task, client=client) for task in tasks if task["name"] != "EDIT"]
         return tasks  # type: ignore
 
     @classmethod
@@ -130,10 +132,11 @@ class VideoTask(DeeplabelBase):
         chunk_size: int = 500,
     ):
         self.client: "deeplabel.client.BaseClient"
-        if not detections: return None
-        assert (isinstance(detections, List) and isinstance(detections[0],
-                deeplabel.infer.videos.detections.Detection)), \
-                f"detections should be of type List[deeplabel.infer.videos.detections.Detection]"
+        if not detections:
+            return None
+        assert isinstance(detections, List) and isinstance(
+            detections[0], deeplabel.infer.videos.detections.Detection
+        ), f"detections should be of type List[deeplabel.infer.videos.detections.Detection]"
 
         def chunk(
             it: Iterable[Any], size: int
@@ -145,21 +148,62 @@ class VideoTask(DeeplabelBase):
         for dets in chunk(detections, chunk_size):
             dets: List[deeplabel.infer.videos.detections.Detection]
             data = [
-                json.loads(det.json(by_alias=True, exclude_none=True))
-                for det in dets
+                json.loads(det.json(by_alias=True, exclude_none=True)) for det in dets
             ]
             logger.debug(f"Pushing ({count} ~ {count+len(data)})/{len(detections)}")
             count += len(data)
-            self.client.post("/detections", {"data": data, "batch": True, "videoTaskId":self.video_task_id})
+            self.client.post(
+                "/detections",
+                {"data": data, "batch": True, "videoTaskId": self.video_task_id},
+            )
         logger.info(
             f"Completed pushing {len(detections)} detections for videoTaskId: {self.video_task_id}"
         )
 
+    def insert_detections_to_s3(
+        self, detections: List["deeplabel.infer.videos.detections.Detection"],
+    ):
+        """Given detections, this API saves the {videoTaskId}_results.json to S3
+        insert_detections is only called for tasks with isShown=True
+        to avoid filling up the db.
+        So, S3 provides previous node detections for all the nodes, not DB
+        """
+        self.client: "deeplabel.client.BaseClient"
+
+        dets = [
+            json.loads(det.json(by_alias=True, exclude_none=True)) for det in detections
+        ]
+        logger.debug(f"Pushing ({len(dets)} detections to S3")
+        self.client.post(
+            "/videos/tasks/upload-detections",
+            {"data": dets, "videoTaskId": self.video_task_id},
+        )
+        logger.info(
+            f"Completed pushing {len(detections)} detections for videoTaskId: {self.video_task_id} to S3"
+        )
+
+    def get_prev_node_detections_from_s3(self) -> List[str]:
+        """For previous nodes in the graph, the detections would have been
+        pushed to s3 using the self.inset_detection_to_s3 here.
+        This function return list of all results.json presigned urls for previous node data
+        """
+        self.client: "deeplabel.client.BaseClient"
+        resp = self.client.get(
+            "/videos/tasks/prev-node",
+            params={"videoTaskId": self.video_task_id, "projectId": self.project_id},
+        )
+        urls = resp.json()["data"]
+        logger.debug(
+            f"Fetched {len(urls)} prev node result urls for "
+            f"videoTaskId {self.video_task_id}"
+        )
+        return urls
+
     @validate_arguments(config=dict(arbitrary_types_allowed=True))
     def update(
         self,
         final_time_points: Optional[List[TimePoint]] = None,
-        progress: Optional[conint(ge=0, le=100)] = None, #type:ignore
+        progress: Optional[conint(ge=0, le=100)] = None,  # type:ignore
         status: Optional[VideoTaskStatus] = None,
     ):
         data = {}
@@ -168,7 +212,7 @@ class VideoTask(DeeplabelBase):
                 tp.dict(by_alias=True) for tp in final_time_points
             ]
         if progress is not None:
-            data["progress"] = progress #type: ignore
+            data["progress"] = progress  # type: ignore
         if status is not None:
             data["status"] = status.value
         if not data:
